@@ -25,6 +25,12 @@
 #include <QDebug>
 #include <QQmlComponent>
 
+#ifdef LOMIRI_ONLINEACCOUNTS_UBUNTU_COMPAT
+#include <QLoggingCategory>
+
+Q_LOGGING_CATEGORY(ldCategory, "lomiri.deprecations", QtWarningMsg)
+#endif
+
 using namespace OnlineAccountsClient;
 
 void Plugin::registerTypes(const char *uri)
@@ -32,4 +38,13 @@ void Plugin::registerTypes(const char *uri)
     qDebug() << Q_FUNC_INFO << uri;
     qmlRegisterType<Setup>(uri, 0, 1, "Setup");
     qmlRegisterType<Setup,2>(uri, 0, 2, "Setup");
+
+#ifdef LOMIRI_ONLINEACCOUNTS_UBUNTU_COMPAT
+    if (uri == QLatin1String("Ubuntu.OnlineAccounts.Client")) {
+        qCDebug(ldCategory, "Use of the Ubuntu.OnlineAccounts.Client namespace "
+                            "is deprecated, please consider updating your "
+                            "applications to import "
+                            "Lomiri.OnlineAccounts.Client instead.");
+    }
+#endif
 }
