@@ -158,7 +158,7 @@ QString ServicePrivate::rootDirForIdentity(quint32 id)
 {
     /* the BrowserRequest class instructs the webview to store its cookies and
      * local data into
-     * ~/.cache/online-accounts-ui/id-<signon-id>-<provider-id>/; while we
+     * ~/.cache/lomiri-online-accounts-ui/id-<signon-id>-<provider-id>/; while we
      * don't normally expect to find more than one entry for a given signon-id,
      * it's a possibility we cannot completely discard, since in older versions
      * we were not appending the "-<provider-id>" suffix. Besides, unless we
@@ -169,7 +169,7 @@ QString ServicePrivate::rootDirForIdentity(quint32 id)
      */
     QString cachePath =
         QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation);
-    QDir cacheDir(cachePath + QStringLiteral("/online-accounts-ui"));
+    QDir cacheDir(cachePath + QStringLiteral("/lomiri-online-accounts-ui"));
     QString nameFilter = QString("id-%1*").arg(id);
     QStringList rootDirs = cacheDir.entryList(QStringList() << nameFilter,
                                               QDir::Dirs, QDir::Time);
