@@ -189,7 +189,7 @@ void ProviderRequestPrivate::allow(int accountId)
     /* If the request came from an app, add a small delay so that we could
      * serve an authentication request coming right after this one. */
     if (m_view->isVisible() &&
-        m_applicationInfo.value("id").toString() != "system-settings") {
+        m_applicationInfo.value("id").toString() != "lomiri-system-settings") {
         q->setDelay(3000);
     }
     QVariantMap result;
