@@ -128,7 +128,7 @@ void ServiceTest::testCookies()
     quint32 id = 47;
 
     QString subDir =
-        QString("online-accounts-ui/id-%2").arg(id);
+        QString("lomiri-online-accounts-ui/id-%2").arg(id);
     QDir identityDir(tempDir.path());
     identityDir.mkpath(subDir);
     identityDir.cd(subDir);
