@@ -72,7 +72,13 @@ void AccessModelTest::initTestCase()
     qputenv("AG_PROVIDERS", TEST_DATA_DIR);
     qputenv("XDG_DATA_HOME", TEST_DATA_DIR);
 
-    qputenv("QML2_IMPORT_PATH", PLUGIN_PATH);
+    /* Environment may be set up for i.e. SSO.OnlineAccounts import */
+    QString newImportPath = QLatin1String(PLUGIN_PATH);
+    QString oldImportPath = qgetenv("QML2_IMPORT_PATH");
+    if (!oldImportPath.isEmpty()) {
+        newImportPath += QStringLiteral(":") + oldImportPath;
+    }
+    qputenv("QML2_IMPORT_PATH", newImportPath.toUtf8());
 
     clearDb();
 }
